

use<threads.scad>
use <Moleteado.scad>


/*[Parámetros de la mordaza]*/

//Largo de la mordaza
Largo_Mordaza = 60;

//Ancho de la mordaza
Ancho_Mordaza = 45;

//Alto de la mordaza
Alto_Mordaza = 55;

//Grosor de la mordaza
Grosor_Mordaza = 20;

//Diámetro del tubo para fijación de la rótula
Tubo = 23.9;

//Largo del tubo para fijación de la rótula
Largo_Tubo = 50;


/*[Parámetros de la rosca]*/

//Diámetro de la rosca
Diametro_Rosca = 16;

//Paso de la rosca
Paso = 3;       //[2:0.5:4]

//Diámetro de la bola
Diametro_Bola = 8;      //[7:1:12]


/*[Parámetros de la palomilla moleteada]*/

//Altura de la palomilla
Alto_Palomilla=12;

//Diámetro de la palomilla
Diametro_Palomilla=40;

//Profundidad de las muescas
Diametro = 25;//[10:0.1:100]

//Número de muescas por fila
Numero_de_Muescas = 40;     //[15:1:50]

Profundidad_de_Muesca = 3.14*(Diametro/2)/Numero_de_Muescas;   

Angulo_Moleteado= Alto_Palomilla/ (Diametro/2.5)*45;

Radio = Diametro_Palomilla/2;


/*[Parámetros de la presilla]*/

//Tolerancia para el encaje de la bola
Tolerancia_Bola = 0.5;      //[0.1:0.1:1]

//Grosor de la presilla
Grosor_Presilla = 5;        //[3:0.5:5]

//Diámetro de la presilla
Diametro_Presilla = 30;


/*[Parámetros generales]*/

//Diámetro del redondeo de los bordes de la mordaza
Redondeo = 4;       //[2:0.5:10]

//Diámetro de la curva de la mordaza
Curva = 20;     //[5:1:40]

//Suavizado de las partes redondeadas
Suavizado = 8;      //[8:4:80]


/*[Mostrar]*/
//Elementos que desea mostrar para su impresión
Mostrar = "Mordaza";     //[Mordaza:Mordaza, Tornillo:Tornillo, Presilla:Presilla]



module Hueco(){
translate([Curva,0,0]) minkowski() {
cube([Largo_Mordaza+Curva+Redondeo,Alto_Mordaza-Curva+Redondeo,Ancho_Mordaza-0.5],center=true);
cylinder(d=Curva,h=1,$fn=80);
}
}


module Hueco2(){
translate([0,0,0])
cube([Largo_Mordaza,Alto_Mordaza,Ancho_Mordaza+5],center=true);
}

module Externo(){
minkowski() {
cube([Largo_Mordaza-Curva+Grosor_Mordaza*2-Redondeo,Alto_Mordaza-Curva+Grosor_Mordaza*2-Redondeo,Ancho_Mordaza-Redondeo-1],center=true);
cylinder(d=Curva,h=1,$fn=80);
}
}

module Base() {
difference() {
Externo();
Hueco2();
translate([Largo_Mordaza-Redondeo/2,0,0]) cube([Largo_Mordaza,Alto_Mordaza+Grosor_Mordaza*3,Ancho_Mordaza+5],center=true);
}
}

module Base_Mordaza() {
minkowski() {
Base();
sphere(d=Redondeo,$fn=Suavizado);
}
}

module Mordaza() {
difference() {
Base_Mordaza();
translate([0,-Alto_Mordaza/4,0]) rotate([90,0,0]) metric_thread(Diametro_Rosca+0.4, Paso, Alto_Mordaza, true, 1);
}
translate([0,(Alto_Mordaza+Grosor_Mordaza*2)/2+Largo_Tubo/2-1,0])rotate([90,0,0]) cylinder(d=Tubo,h=Largo_Tubo,$fn=80,center=true);
}



module Tornillo(){
    Moleteado(Radio,Alto_Palomilla,Numero_de_Muescas,Profundidad_de_Muesca/1.3,Angulo_Moleteado);
    translate([0,0,Alto_Palomilla]) metric_thread(Diametro_Rosca, Paso, Alto_Mordaza, false, 1);
    translate([0,0,Alto_Palomilla+Alto_Mordaza])cylinder(h=6,d=6,$fn=40);
    translate([0,0,Alto_Palomilla+Alto_Mordaza+5])sphere(d=Diametro_Bola,$fn=40);
}


module Redondeado(d=20,h=5,r=2){
  translate([0,0,r])
    minkowski(){
      cylinder(d=d-r*2,h=h-r*2, $fn=160);
      sphere(r=r);
    }
}


module Presilla(){
    $fn=80;
    difference(){
      union(){
        Redondeado(d=Diametro_Presilla,h=Grosor_Presilla,r=1);
        Redondeado(d=Diametro_Bola+5,h=Diametro_Bola+3,r=1);
        }
      translate([0,0,Diametro_Bola])sphere(d=Diametro_Bola+Tolerancia_Bola);
      for (i=[0,120,240])
        translate([0,0,6.5])rotate([90,0,90+i])hull(){
          cylinder(d=3,h=10);
          translate([0,Diametro_Bola+3,0])cylinder(d=3,h=10);
        }
    }
}


if (Mostrar=="Mordaza") {
    Mordaza();
}

if (Mostrar=="Tornillo") {
    Tornillo();
}

if (Mostrar=="Presilla") {
    Presilla();
}


